|pypi| |docs| |ci| |cov|


riopg
-----

``riopg`` is a small wrapper for psycopg2 that allows connecting to PostgreSQL databases
asynchronously using the ``curio`` or ``trio`` libraries.

For more information, see the docs at https://riopg.readthedocs.io/en/latest/ .


.. |pypi| image:: https://img.shields.io/pypi/v/riopg.svg?style=for-the-badge
    :alt: PyPI
.. |docs| image:: https://img.shields.io/badge/docs-read%20now-blue.svg?style=for-the-badge
   :target: https://riopg.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. |ci| image:: https://img.shields.io/circleci/project/github/Fuyukai/riopg.svg?style=for-the-badge
    :alt: CircleCI
    :target: https://circleci.com/gh/Fuyukai/riopg/
.. |cov| image:: https://img.shields.io/codecov/c/github/Fuyukai/riopg.svg?style=for-the-badge
    :alt: Codecov